@@ -37,7 +37,7 @@ from typing import Any, Dict, Generator, List, Type, TypeVar
 https://stackoverflow.com/questions/1776994
 https://docs.python.org/3/library/inspect.html
 https://github.com/edoburu/django-fluent-contents/issues/43
-https://bytes.com/topic/python/answers/843424-python-2-6-3-0-determining-if-method-inherited  # noqa
+https://bytes.com/topic/python/answers/843424-python-2-6-3-0-determining-if-method-inherited  # noqa: E501
 https://docs.python.org/3/reference/datamodel.html
 
 In Python 2, you can do this:
@@ -105,7 +105,7 @@ def derived_class_implements_method(
 # =============================================================================
 # Subclasses
 # =============================================================================
-# https://stackoverflow.com/questions/3862310/how-can-i-find-all-subclasses-of-a-class-given-its-name  # noqa
+# https://stackoverflow.com/questions/3862310/how-can-i-find-all-subclasses-of-a-class-given-its-name  # noqa: E501
 
 
 def gen_all_subclasses(cls: Type) -> Generator[Type, None, None]:
