@@ -150,7 +150,7 @@ def preserve_cwd(func: Callable) -> Callable:
         myfunc()
         assert os.getcwd() == "/home"
     """
-    # https://stackoverflow.com/questions/169070/python-how-do-i-write-a-decorator-that-restores-the-cwd  # noqa
+    # https://stackoverflow.com/questions/169070/python-how-do-i-write-a-decorator-that-restores-the-cwd  # noqa: E501
     def decorator(*args_, **kwargs) -> Any:
         cwd = os.getcwd()
         result = func(*args_, **kwargs)
@@ -353,7 +353,7 @@ def shutil_rmtree_onerror(
 
     See
     https://stackoverflow.com/questions/2656322/shutil-rmtree-fails-on-windows-with-access-is-denied
-    """  # noqa
+    """
     if not os.access(path, os.W_OK):
         # Is the error an access error ?
         os.chmod(path, stat.S_IWUSR)
@@ -539,7 +539,7 @@ def get_directory_contents_size(directory: str = ".") -> int:
 
     Returns:
         int: size in bytes
-    """  # noqa
+    """
     total_size = 0
     for dirpath, dirnames, filenames in os.walk(directory):
         for f in filenames:
